@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import os
 import typing
 from io import BytesIO
@@ -21,7 +19,7 @@ def df_to_json_response(df: pd.DataFrame) -> Response:
     )
 
 
-def create_app(store: Store, testing: bool = False) -> FastAPI:
+def create_fastapi_app(store: Store, testing: bool = False) -> FastAPI:
     # Security
     MOTION_API_TOKEN = os.environ.get("MOTION_API_TOKEN")
     if not MOTION_API_TOKEN:
@@ -136,6 +134,10 @@ def create_app(store: Store, testing: bool = False) -> FastAPI:
     async def session_id() -> typing.Any:
         return app.state.store.session_id
 
+    @app.post("/checkpoint/")
+    async def checkpoint() -> typing.Any:
+        return app.state.store.checkpoint_pa()
+
     @app.on_event("shutdown")
     async def shutdown() -> None:
         if not app.state.testing:
